/***************************************************************************
 *   Copyright (C) 2007 Nicolas Hadacek <hadacek@kde.org>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#include "progress_monitor.h"

#include "common/common/misc.h"

ProgressMonitor::ProgressMonitor(QObject* parent)
  : QObject(parent, "progress_monitor"), _current(-1)
{}

void ProgressMonitor::clear()
{
  _current = -1;
  _tasks.clear();
}

void ProgressMonitor::appendTask(const QString &label, uint nbSteps)
{
  Task task;
  task.label = label;
  task.nbSteps = nbSteps;
  task.nbDoneSteps = 0;
  _tasks.append(task);
}

uint ProgressMonitor::nbSteps() const
{
  uint nb = 0;
  for (uint i=0; i<uint(_tasks.count()); i++) nb += _tasks[i].nbSteps;
  return nb;
}

uint ProgressMonitor::nbDoneSteps() const
{
  uint nb = 0;
  for (uint i=0; i<uint(_tasks.count()); i++) nb += _tasks[i].nbDoneSteps;
  return nb;
}

void ProgressMonitor::update()
{
  if ( _current==-1 ) return;
  CRASH_ASSERT( int(_tasks.count())>_current );
  emit setLabel(_tasks[_current].label);
  emit setProgress(nbDoneSteps());
}

void ProgressMonitor::startNextTask()
{
  if ( _current==-1 ) emit setTotalProgress(nbSteps());
  if ( (_current+1)<int(_tasks.count()) ) _current++;
  update();
}

void ProgressMonitor::addTaskProgress(uint nbSteps)
{
  CRASH_ASSERT( _current!=-1 );
  CRASH_ASSERT( int(_tasks.count())>_current );
  uint nb = _tasks[_current].nbDoneSteps + nbSteps;
  Q_ASSERT( nb<=_tasks[_current].nbSteps );
  if ( nb>_tasks[_current].nbSteps ) qDebug("%s %i+%i/%i", _tasks[_current].label.latin1(), _tasks[_current].nbDoneSteps, nbSteps, _tasks[_current].nbSteps);
  _tasks[_current].nbDoneSteps = QMIN(nb, _tasks[_current].nbSteps);
  update();
}

void ProgressMonitor::finishTask()
{
  CRASH_ASSERT( _current!=-1 );
  CRASH_ASSERT( int(_tasks.count())>_current );
  _tasks[_current].nbDoneSteps = _tasks[_current].nbSteps;
  update();
}
